from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D.Dxc
import win32more.Windows.Win32.System.Com
CLSID_DxcUtils: Guid = Guid('{6245d6af-66e0-48fd-80b4-4d271796748c}')
DXC_HASHFLAG_INCLUDES_SOURCE: UInt32 = 1
DXC_ARG_DEBUG: String = '-Zi'
DXC_ARG_SKIP_VALIDATION: String = '-Vd'
DXC_ARG_SKIP_OPTIMIZATIONS: String = '-Od'
DXC_ARG_PACK_MATRIX_ROW_MAJOR: String = '-Zpr'
DXC_ARG_PACK_MATRIX_COLUMN_MAJOR: String = '-Zpc'
DXC_ARG_AVOID_FLOW_CONTROL: String = '-Gfa'
DXC_ARG_PREFER_FLOW_CONTROL: String = '-Gfp'
DXC_ARG_ENABLE_STRICTNESS: String = '-Ges'
DXC_ARG_ENABLE_BACKWARDS_COMPATIBILITY: String = '-Gec'
DXC_ARG_IEEE_STRICTNESS: String = '-Gis'
DXC_ARG_OPTIMIZATION_LEVEL0: String = '-O0'
DXC_ARG_OPTIMIZATION_LEVEL1: String = '-O1'
DXC_ARG_OPTIMIZATION_LEVEL2: String = '-O2'
DXC_ARG_OPTIMIZATION_LEVEL3: String = '-O3'
DXC_ARG_WARNINGS_ARE_ERRORS: String = '-WX'
DXC_ARG_RESOURCES_MAY_ALIAS: String = '-res_may_alias'
DXC_ARG_ALL_RESOURCES_BOUND: String = '-all_resources_bound'
DXC_ARG_DEBUG_NAME_FOR_SOURCE: String = '-Zss'
DXC_ARG_DEBUG_NAME_FOR_BINARY: String = '-Zsb'
DXC_EXTRA_OUTPUT_NAME_STDOUT: String = '*stdout*'
DXC_EXTRA_OUTPUT_NAME_STDERR: String = '*stderr*'
DxcValidatorFlags_Default: UInt32 = 0
DxcValidatorFlags_InPlaceEdit: UInt32 = 1
DxcValidatorFlags_RootSignatureOnly: UInt32 = 2
DxcValidatorFlags_ModuleOnly: UInt32 = 4
DxcValidatorFlags_ValidMask: UInt32 = 7
DxcVersionInfoFlags_None: UInt32 = 0
DxcVersionInfoFlags_Debug: UInt32 = 1
DxcVersionInfoFlags_Internal: UInt32 = 2
CLSID_DxcCompiler: Guid = Guid('{73e22d93-e6ce-47f3-b5bf-f0664f39c1b0}')
CLSID_DxcLinker: Guid = Guid('{ef6a8087-b0ea-4d56-9e45-d07e1a8b7806}')
CLSID_DxcDiaDataSource: Guid = Guid('{cd1f6b73-2ab0-484d-8edc-ebe7a43ca09f}')
CLSID_DxcCompilerArgs: Guid = Guid('{3e56ae82-224d-470f-a1a1-fe3016ee9f9d}')
CLSID_DxcLibrary: Guid = Guid('{6245d6af-66e0-48fd-80b4-4d271796748c}')
CLSID_DxcValidator: Guid = Guid('{8ca3e215-f728-4cf3-8cdd-88af917587a1}')
CLSID_DxcAssembler: Guid = Guid('{d728db68-f903-4f80-94cd-dccf76ec7151}')
CLSID_DxcContainerReflection: Guid = Guid('{b9f54489-55b8-400c-ba3a-1675e4728b91}')
CLSID_DxcOptimizer: Guid = Guid('{ae2cd79f-cc22-453f-9b6b-b124e7a5204c}')
CLSID_DxcContainerBuilder: Guid = Guid('{94134294-411f-4574-b4d0-8741e25240d2}')
CLSID_DxcPdbUtils: Guid = Guid('{54621dfb-f2ce-457e-ae8c-ec355faeec7c}')
@winfunctype('dxcompiler.dll')
def DxcCreateInstance(rclsid: POINTER(Guid), riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('dxcompiler.dll')
def DxcCreateInstance2(pMalloc: win32more.Windows.Win32.System.Com.IMalloc, rclsid: POINTER(Guid), riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
DXC_CP = UInt32
DXC_CP_ACP: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP = 0
DXC_CP_UTF16: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP = 1200
DXC_CP_UTF8: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP = 65001
DXC_OUT_KIND = Int32
DXC_OUT_NONE: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 0
DXC_OUT_OBJECT: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 1
DXC_OUT_ERRORS: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 2
DXC_OUT_PDB: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 3
DXC_OUT_SHADER_HASH: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 4
DXC_OUT_DISASSEMBLY: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 5
DXC_OUT_HLSL: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 6
DXC_OUT_TEXT: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 7
DXC_OUT_REFLECTION: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 8
DXC_OUT_ROOT_SIGNATURE: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 9
DXC_OUT_EXTRA_OUTPUTS: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND = 10
class DxcArgPair(Structure):
    pName: win32more.Windows.Win32.Foundation.PWSTR
    pValue: win32more.Windows.Win32.Foundation.PWSTR
class DxcBuffer(Structure):
    Ptr: VoidPtr
    Size: UIntPtr
    Encoding: UInt32
@winfunctype_pointer
def DxcCreateInstance2Proc(pMalloc: win32more.Windows.Win32.System.Com.IMalloc, rclsid: POINTER(Guid), riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def DxcCreateInstanceProc(rclsid: POINTER(Guid), riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class DxcDefine(Structure):
    Name: win32more.Windows.Win32.Foundation.PWSTR
    Value: win32more.Windows.Win32.Foundation.PWSTR
class DxcShaderHash(Structure):
    Flags: UInt32
    HashDigest: Byte * 16
class IDxcAssembler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{091f7a26-1c1f-4948-904b-e6e3a8a771d5}')
    @commethod(3)
    def AssembleToContainer(self, pShader: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcBlob(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8ba5fb08-5195-40e2-ac58-0d989c3a0102}')
    @commethod(3)
    def GetBufferPointer(self) -> VoidPtr: ...
    @commethod(4)
    def GetBufferSize(self) -> UIntPtr: ...
class IDxcBlobEncoding(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob
    _iid_ = Guid('{7241d424-2646-4191-97c0-98e96e42fc68}')
    @commethod(5)
    def GetEncoding(self, pKnown: POINTER(win32more.Windows.Win32.Foundation.BOOL), pCodePage: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcBlobUtf16(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding
    _iid_ = Guid('{a3f84eab-0faa-497e-a39c-ee6ed60b2d84}')
    @commethod(6)
    def GetStringPointer(self) -> win32more.Windows.Win32.Foundation.PWSTR: ...
    @commethod(7)
    def GetStringLength(self) -> UIntPtr: ...
class IDxcBlobUtf8(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding
    _iid_ = Guid('{3da636c9-ba71-4024-a301-30cbf125305b}')
    @commethod(6)
    def GetStringPointer(self) -> win32more.Windows.Win32.Foundation.PSTR: ...
    @commethod(7)
    def GetStringLength(self) -> UIntPtr: ...
class IDxcCompiler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8c210bf3-011f-4422-8d70-6f9acb8db617}')
    @commethod(3)
    def Compile(self, pSource: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, pSourceName: win32more.Windows.Win32.Foundation.PWSTR, pEntryPoint: win32more.Windows.Win32.Foundation.PWSTR, pTargetProfile: win32more.Windows.Win32.Foundation.PWSTR, pArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), argCount: UInt32, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcDefine), defineCount: UInt32, pIncludeHandler: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcIncludeHandler, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Preprocess(self, pSource: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, pSourceName: win32more.Windows.Win32.Foundation.PWSTR, pArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), argCount: UInt32, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcDefine), defineCount: UInt32, pIncludeHandler: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcIncludeHandler, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Disassemble(self, pSource: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, ppDisassembly: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcCompiler2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcCompiler
    _iid_ = Guid('{a005a9d9-b8bb-4594-b5c9-0e633bec4d37}')
    @commethod(6)
    def CompileWithDebug(self, pSource: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, pSourceName: win32more.Windows.Win32.Foundation.PWSTR, pEntryPoint: win32more.Windows.Win32.Foundation.PWSTR, pTargetProfile: win32more.Windows.Win32.Foundation.PWSTR, pArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), argCount: UInt32, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcDefine), defineCount: UInt32, pIncludeHandler: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcIncludeHandler, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult), ppDebugBlobName: POINTER(win32more.Windows.Win32.Foundation.PWSTR), ppDebugBlob: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcCompiler3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{228b4687-5a6a-4730-900c-9702b2203f54}')
    @commethod(3)
    def Compile(self, pSource: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcBuffer), pArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), argCount: UInt32, pIncludeHandler: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcIncludeHandler, riid: POINTER(Guid), ppResult: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Disassemble(self, pObject: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcBuffer), riid: POINTER(Guid), ppResult: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcCompilerArgs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{73effe2a-70dc-45f8-9690-eff64c02429d}')
    @commethod(3)
    def GetArguments(self) -> POINTER(win32more.Windows.Win32.Foundation.PWSTR): ...
    @commethod(4)
    def GetCount(self) -> UInt32: ...
    @commethod(5)
    def AddArguments(self, pArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), argCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddArgumentsUTF8(self, pArguments: POINTER(win32more.Windows.Win32.Foundation.PSTR), argCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddDefines(self, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcDefine), defineCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcContainerBuilder(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{334b1f50-2292-4b35-99a1-25588d8c17fe}')
    @commethod(3)
    def Load(self, pDxilContainerHeader: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AddPart(self, fourCC: UInt32, pSource: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RemovePart(self, fourCC: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SerializeContainer(self, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcContainerReflection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d2c21b26-8350-4bdc-976a-331ce6f4c54c}')
    @commethod(3)
    def Load(self, pContainer: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPartCount(self, pResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPartKind(self, idx: UInt32, pResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetPartContent(self, idx: UInt32, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindFirstPartKind(self, kind: UInt32, pResult: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPartReflection(self, idx: UInt32, iid: POINTER(Guid), ppvObject: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcExtraOutputs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{319b37a2-a5c2-494a-a5de-4801b2faf989}')
    @commethod(3)
    def GetOutputCount(self) -> UInt32: ...
    @commethod(4)
    def GetOutput(self, uIndex: UInt32, iid: POINTER(Guid), ppvObject: POINTER(VoidPtr), ppOutputType: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobUtf16), ppOutputName: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobUtf16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcIncludeHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7f61fc7d-950d-467f-b3e3-3c02fb49187c}')
    @commethod(3)
    def LoadSource(self, pFilename: win32more.Windows.Win32.Foundation.PWSTR, ppIncludeSource: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcLibrary(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e5204dc7-d18c-4c3c-bdfb-851673980fe7}')
    @commethod(3)
    def SetMalloc(self, pMalloc: win32more.Windows.Win32.System.Com.IMalloc) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateBlobFromBlob(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, offset: UInt32, length: UInt32, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateBlobFromFile(self, pFileName: win32more.Windows.Win32.Foundation.PWSTR, codePage: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP), pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateBlobWithEncodingFromPinned(self, pText: VoidPtr, size: UInt32, codePage: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateBlobWithEncodingOnHeapCopy(self, pText: VoidPtr, size: UInt32, codePage: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateBlobWithEncodingOnMalloc(self, pText: VoidPtr, pIMalloc: win32more.Windows.Win32.System.Com.IMalloc, size: UInt32, codePage: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateIncludeHandler(self, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcIncludeHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CreateStreamFromBlobReadOnly(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, ppStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetBlobAsUtf8(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetBlobAsUtf16(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcLinker(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f1b5be2a-62dd-4327-a1c2-42ac1e1e78e6}')
    @commethod(3)
    def RegisterLibrary(self, pLibName: win32more.Windows.Win32.Foundation.PWSTR, pLib: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Link(self, pEntryName: win32more.Windows.Win32.Foundation.PWSTR, pTargetProfile: win32more.Windows.Win32.Foundation.PWSTR, pLibNames: POINTER(win32more.Windows.Win32.Foundation.PWSTR), libCount: UInt32, pArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), argCount: UInt32, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcOperationResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cedb484a-d4e9-445a-b991-ca21ca157dc2}')
    @commethod(3)
    def GetStatus(self, pStatus: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetResult(self, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetErrorBuffer(self, ppErrors: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcOptimizer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{25740e2e-9cba-401b-9119-4fb42f39f270}')
    @commethod(3)
    def GetAvailablePassCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAvailablePass(self, index: UInt32, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOptimizerPass)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def RunOptimizer(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, ppOptions: POINTER(win32more.Windows.Win32.Foundation.PWSTR), optionCount: UInt32, pOutputModule: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob), ppOutputText: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcOptimizerPass(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ae2cd79f-cc22-453f-9b6b-b124e7a5204c}')
    @commethod(3)
    def GetOptionName(self, ppResult: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDescription(self, ppResult: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetOptionArgCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetOptionArgName(self, argIndex: UInt32, ppResult: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetOptionArgDescription(self, argIndex: UInt32, ppResult: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcPdbUtils(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e6c9647e-9d6a-4c3b-b94c-524b5a6c343d}')
    @commethod(3)
    def Load(self, pPdbOrDxil: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSourceCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSource(self, uIndex: UInt32, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSourceName(self, uIndex: UInt32, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetFlagCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetFlag(self, uIndex: UInt32, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetArgCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetArg(self, uIndex: UInt32, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetArgPairCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetArgPair(self, uIndex: UInt32, pName: POINTER(win32more.Windows.Win32.Foundation.BSTR), pValue: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetDefineCount(self, pCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetDefine(self, uIndex: UInt32, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetTargetProfile(self, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetEntryPoint(self, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetMainFileName(self, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetHash(self, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetName(self, pResult: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def IsFullPDB(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(21)
    def GetFullPDB(self, ppFullPDB: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetVersionInfo(self, ppVersionInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcVersionInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def SetCompiler(self, pCompiler: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcCompiler3) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def CompileForFullPDB(self, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def OverrideArgs(self, pArgPairs: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcArgPair), uNumArgPairs: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def OverrideRootSignature(self, pRootSignature: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcResult(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult
    _iid_ = Guid('{58346cda-dde7-4497-9461-6f87af5e0659}')
    @commethod(6)
    def HasOutput(self, dxcOutKind: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(7)
    def GetOutput(self, dxcOutKind: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND, iid: POINTER(Guid), ppvObject: POINTER(VoidPtr), ppOutputName: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobUtf16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetNumOutputs(self) -> UInt32: ...
    @commethod(9)
    def GetOutputByIndex(self, Index: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND: ...
    @commethod(10)
    def PrimaryOutput(self) -> win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_OUT_KIND: ...
class IDxcUtils(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4605c4cb-2019-492a-ada4-65f20bb7d67f}')
    @commethod(3)
    def CreateBlobFromBlob(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, offset: UInt32, length: UInt32, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateBlobFromPinned(self, pData: VoidPtr, size: UInt32, codePage: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def MoveToBlob(self, pData: VoidPtr, pIMalloc: win32more.Windows.Win32.System.Com.IMalloc, size: UInt32, codePage: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateBlob(self, pData: VoidPtr, size: UInt32, codePage: win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def LoadFile(self, pFileName: win32more.Windows.Win32.Foundation.PWSTR, pCodePage: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DXC_CP), pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobEncoding)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateReadOnlyStreamFromBlob(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, ppStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateDefaultIncludeHandler(self, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcIncludeHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetBlobAsUtf8(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobUtf8)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetBlobAsUtf16(self, pBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, pBlobEncoding: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlobUtf16)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDxilContainerPart(self, pShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcBuffer), DxcPart: UInt32, ppPartData: POINTER(VoidPtr), pPartSizeInBytes: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateReflection(self, pData: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcBuffer), iid: POINTER(Guid), ppvReflection: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def BuildArguments(self, pSourceName: win32more.Windows.Win32.Foundation.PWSTR, pEntryPoint: win32more.Windows.Win32.Foundation.PWSTR, pTargetProfile: win32more.Windows.Win32.Foundation.PWSTR, pArguments: POINTER(win32more.Windows.Win32.Foundation.PWSTR), argCount: UInt32, pDefines: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcDefine), defineCount: UInt32, ppArgs: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcCompilerArgs)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetPDBContents(self, pPDBBlob: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, ppHash: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob), ppContainer: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcValidator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a6e82bd2-1fd7-4826-9811-2857e797f49a}')
    @commethod(3)
    def Validate(self, pShader: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, Flags: UInt32, ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcValidator2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcValidator
    _iid_ = Guid('{458e1fd1-b1b2-4750-a6e1-9c10f03bed92}')
    @commethod(4)
    def ValidateWithDebug(self, pShader: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcBlob, Flags: UInt32, pOptDebugBitcode: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.DxcBuffer), ppResult: POINTER(win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcOperationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcVersionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b04f5b50-2059-4f12-a8ff-a1e0cde1cc7e}')
    @commethod(3)
    def GetVersion(self, pMajor: POINTER(UInt32), pMinor: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFlags(self, pFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcVersionInfo2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D.Dxc.IDxcVersionInfo
    _iid_ = Guid('{fb6904c4-42f0-4b62-9c46-983af7da7c83}')
    @commethod(5)
    def GetCommitInfo(self, pCommitCount: POINTER(UInt32), pCommitHash: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDxcVersionInfo3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5e13e843-9d25-473c-9ad2-03b2d0b44b1e}')
    @commethod(3)
    def GetCustomVersionString(self, pVersionString: POINTER(POINTER(SByte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Security.Credentials
import win32more.Windows.System
import win32more.Windows.UI.ApplicationSettings
import win32more.Windows.UI.Popups
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class AccountsSettingsPane(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPane
    _classid_ = 'Windows.UI.ApplicationSettings.AccountsSettingsPane'
    @winrt_mixinmethod
    def add_AccountCommandsRequested(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPane, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.ApplicationSettings.AccountsSettingsPane, win32more.Windows.UI.ApplicationSettings.AccountsSettingsPaneCommandsRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AccountCommandsRequested(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPane, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def ShowManageAccountsForUserAsync(cls: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics3, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def ShowAddAccountForUserAsync(cls: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics3, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def ShowManageAccountsAsync(cls: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics2) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def ShowAddAccountAsync(cls: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics2) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics) -> win32more.Windows.UI.ApplicationSettings.AccountsSettingsPane: ...
    @winrt_classmethod
    def Show(cls: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics) -> Void: ...
    AccountCommandsRequested = event()
class AccountsSettingsPaneCommandsRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs
    _classid_ = 'Windows.UI.ApplicationSettings.AccountsSettingsPaneCommandsRequestedEventArgs'
    @winrt_mixinmethod
    def get_WebAccountProviderCommands(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommand]: ...
    @winrt_mixinmethod
    def get_WebAccountCommands(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.WebAccountCommand]: ...
    @winrt_mixinmethod
    def get_CredentialCommands(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.CredentialCommand]: ...
    @winrt_mixinmethod
    def get_Commands(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.SettingsCommand]: ...
    @winrt_mixinmethod
    def get_HeaderText(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_HeaderText(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs) -> win32more.Windows.UI.ApplicationSettings.AccountsSettingsPaneEventDeferral: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs2) -> win32more.Windows.System.User: ...
    Commands = property(get_Commands, None)
    CredentialCommands = property(get_CredentialCommands, None)
    HeaderText = property(get_HeaderText, put_HeaderText)
    User = property(get_User, None)
    WebAccountCommands = property(get_WebAccountCommands, None)
    WebAccountProviderCommands = property(get_WebAccountProviderCommands, None)
class AccountsSettingsPaneEventDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneEventDeferral
    _classid_ = 'Windows.UI.ApplicationSettings.AccountsSettingsPaneEventDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Windows.UI.ApplicationSettings.IAccountsSettingsPaneEventDeferral) -> Void: ...
ApplicationsSettingsContract: UInt32 = 65536
class CredentialCommand(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.ICredentialCommand
    _classid_ = 'Windows.UI.ApplicationSettings.CredentialCommand'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.UI.ApplicationSettings.CredentialCommand.CreateCredentialCommand(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.UI.ApplicationSettings.CredentialCommand.CreateCredentialCommandWithHandler(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateCredentialCommand(cls: win32more.Windows.UI.ApplicationSettings.ICredentialCommandFactory, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential) -> win32more.Windows.UI.ApplicationSettings.CredentialCommand: ...
    @winrt_factorymethod
    def CreateCredentialCommandWithHandler(cls: win32more.Windows.UI.ApplicationSettings.ICredentialCommandFactory, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential, deleted: win32more.Windows.UI.ApplicationSettings.CredentialCommandCredentialDeletedHandler) -> win32more.Windows.UI.ApplicationSettings.CredentialCommand: ...
    @winrt_mixinmethod
    def get_PasswordCredential(self: win32more.Windows.UI.ApplicationSettings.ICredentialCommand) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_mixinmethod
    def get_CredentialDeleted(self: win32more.Windows.UI.ApplicationSettings.ICredentialCommand) -> win32more.Windows.UI.ApplicationSettings.CredentialCommandCredentialDeletedHandler: ...
    CredentialDeleted = property(get_CredentialDeleted, None)
    PasswordCredential = property(get_PasswordCredential, None)
class CredentialCommandCredentialDeletedHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{61c0e185-0977-4678-b4e2-98727afbeed9}')
    @winrt_commethod(3)
    def Invoke(self, command: win32more.Windows.UI.ApplicationSettings.CredentialCommand) -> Void: ...
class IAccountsSettingsPane(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IAccountsSettingsPane'
    _iid_ = Guid('{81ea942c-4f09-4406-a538-838d9b14b7e6}')
    @winrt_commethod(6)
    def add_AccountCommandsRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.ApplicationSettings.AccountsSettingsPane, win32more.Windows.UI.ApplicationSettings.AccountsSettingsPaneCommandsRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_AccountCommandsRequested(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AccountCommandsRequested = event()
class IAccountsSettingsPaneCommandsRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs'
    _iid_ = Guid('{3b68c099-db19-45d0-9abf-95d3773c9330}')
    @winrt_commethod(6)
    def get_WebAccountProviderCommands(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommand]: ...
    @winrt_commethod(7)
    def get_WebAccountCommands(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.WebAccountCommand]: ...
    @winrt_commethod(8)
    def get_CredentialCommands(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.CredentialCommand]: ...
    @winrt_commethod(9)
    def get_Commands(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.SettingsCommand]: ...
    @winrt_commethod(10)
    def get_HeaderText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_HeaderText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def GetDeferral(self) -> win32more.Windows.UI.ApplicationSettings.AccountsSettingsPaneEventDeferral: ...
    Commands = property(get_Commands, None)
    CredentialCommands = property(get_CredentialCommands, None)
    HeaderText = property(get_HeaderText, put_HeaderText)
    WebAccountCommands = property(get_WebAccountCommands, None)
    WebAccountProviderCommands = property(get_WebAccountProviderCommands, None)
class IAccountsSettingsPaneCommandsRequestedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IAccountsSettingsPaneCommandsRequestedEventArgs2'
    _iid_ = Guid('{362f7bad-4e37-4967-8c40-e78ee7a1e5bb}')
    @winrt_commethod(6)
    def get_User(self) -> win32more.Windows.System.User: ...
    User = property(get_User, None)
class IAccountsSettingsPaneEventDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IAccountsSettingsPaneEventDeferral'
    _iid_ = Guid('{cbf25d3f-e5ba-40ef-93da-65e096e5fb04}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IAccountsSettingsPaneStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics'
    _iid_ = Guid('{561f8b60-b0ec-4150-a8dc-208ee44b068a}')
    @winrt_commethod(6)
    def GetForCurrentView(self) -> win32more.Windows.UI.ApplicationSettings.AccountsSettingsPane: ...
    @winrt_commethod(7)
    def Show(self) -> Void: ...
class IAccountsSettingsPaneStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics2'
    _iid_ = Guid('{d21df7c2-ce0d-484f-b8e8-e823c215765e}')
    @winrt_commethod(6)
    def ShowManageAccountsAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ShowAddAccountAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class IAccountsSettingsPaneStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IAccountsSettingsPaneStatics3'
    _iid_ = Guid('{08410458-a2ba-4c6f-b4ac-48f514331216}')
    @winrt_commethod(6)
    def ShowManageAccountsForUserAsync(self, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ShowAddAccountForUserAsync(self, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IAsyncAction: ...
class ICredentialCommand(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ICredentialCommand'
    _iid_ = Guid('{a5f665e6-6143-4a7a-a971-b017ba978ce2}')
    @winrt_commethod(6)
    def get_PasswordCredential(self) -> win32more.Windows.Security.Credentials.PasswordCredential: ...
    @winrt_commethod(7)
    def get_CredentialDeleted(self) -> win32more.Windows.UI.ApplicationSettings.CredentialCommandCredentialDeletedHandler: ...
    CredentialDeleted = property(get_CredentialDeleted, None)
    PasswordCredential = property(get_PasswordCredential, None)
class ICredentialCommandFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ICredentialCommandFactory'
    _iid_ = Guid('{27e88c17-bc3e-4b80-9495-4ed720e48a91}')
    @winrt_commethod(6)
    def CreateCredentialCommand(self, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential) -> win32more.Windows.UI.ApplicationSettings.CredentialCommand: ...
    @winrt_commethod(7)
    def CreateCredentialCommandWithHandler(self, passwordCredential: win32more.Windows.Security.Credentials.PasswordCredential, deleted: win32more.Windows.UI.ApplicationSettings.CredentialCommandCredentialDeletedHandler) -> win32more.Windows.UI.ApplicationSettings.CredentialCommand: ...
class ISettingsCommandFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ISettingsCommandFactory'
    _iid_ = Guid('{68e15b33-1c83-433a-aa5a-ceeea5bd4764}')
    @winrt_commethod(6)
    def CreateSettingsCommand(self, settingsCommandId: win32more.Windows.Win32.System.WinRT.IInspectable, label: WinRT_String, handler: win32more.Windows.UI.Popups.UICommandInvokedHandler) -> win32more.Windows.UI.ApplicationSettings.SettingsCommand: ...
class ISettingsCommandStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ISettingsCommandStatics'
    _iid_ = Guid('{749ae954-2f69-4b17-8aba-d05ce5778e46}')
    @winrt_commethod(6)
    def get_AccountsCommand(self) -> win32more.Windows.UI.ApplicationSettings.SettingsCommand: ...
    AccountsCommand = property(get_AccountsCommand, None)
class ISettingsPane(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ISettingsPane'
    _iid_ = Guid('{b1cd0932-4570-4c69-8d38-89446561ace0}')
    @winrt_commethod(6)
    def add_CommandsRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.ApplicationSettings.SettingsPane, win32more.Windows.UI.ApplicationSettings.SettingsPaneCommandsRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_CommandsRequested(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CommandsRequested = event()
class ISettingsPaneCommandsRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ISettingsPaneCommandsRequest'
    _iid_ = Guid('{44df23ae-5d6e-4068-a168-f47643182114}')
    @winrt_commethod(6)
    def get_ApplicationCommands(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.SettingsCommand]: ...
    ApplicationCommands = property(get_ApplicationCommands, None)
class ISettingsPaneCommandsRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ISettingsPaneCommandsRequestedEventArgs'
    _iid_ = Guid('{205f5d24-1b48-4629-a6ca-2fdfedafb75d}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.UI.ApplicationSettings.SettingsPaneCommandsRequest: ...
    Request = property(get_Request, None)
class ISettingsPaneStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.ISettingsPaneStatics'
    _iid_ = Guid('{1c6a52c5-ff19-471b-ba6b-f8f35694ad9a}')
    @winrt_commethod(6)
    def GetForCurrentView(self) -> win32more.Windows.UI.ApplicationSettings.SettingsPane: ...
    @winrt_commethod(7)
    def Show(self) -> Void: ...
    @winrt_commethod(8)
    def get_Edge(self) -> win32more.Windows.UI.ApplicationSettings.SettingsEdgeLocation: ...
    Edge = property(get_Edge, None)
class IWebAccountCommand(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IWebAccountCommand'
    _iid_ = Guid('{caa39398-9cfa-4246-b0c4-a913a3896541}')
    @winrt_commethod(6)
    def get_WebAccount(self) -> win32more.Windows.Security.Credentials.WebAccount: ...
    @winrt_commethod(7)
    def get_Invoked(self) -> win32more.Windows.UI.ApplicationSettings.WebAccountCommandInvokedHandler: ...
    @winrt_commethod(8)
    def get_Actions(self) -> win32more.Windows.UI.ApplicationSettings.SupportedWebAccountActions: ...
    Actions = property(get_Actions, None)
    Invoked = property(get_Invoked, None)
    WebAccount = property(get_WebAccount, None)
class IWebAccountCommandFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IWebAccountCommandFactory'
    _iid_ = Guid('{bfa6cdff-2f2d-42f5-81de-1d56bafc496d}')
    @winrt_commethod(6)
    def CreateWebAccountCommand(self, webAccount: win32more.Windows.Security.Credentials.WebAccount, invoked: win32more.Windows.UI.ApplicationSettings.WebAccountCommandInvokedHandler, actions: win32more.Windows.UI.ApplicationSettings.SupportedWebAccountActions) -> win32more.Windows.UI.ApplicationSettings.WebAccountCommand: ...
class IWebAccountInvokedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IWebAccountInvokedArgs'
    _iid_ = Guid('{e7abcc40-a1d8-4c5d-9a7f-1d34b2f90ad2}')
    @winrt_commethod(6)
    def get_Action(self) -> win32more.Windows.UI.ApplicationSettings.WebAccountAction: ...
    Action = property(get_Action, None)
class IWebAccountProviderCommand(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IWebAccountProviderCommand'
    _iid_ = Guid('{d69bdd9a-a0a6-4e9b-88dc-c71e757a3501}')
    @winrt_commethod(6)
    def get_WebAccountProvider(self) -> win32more.Windows.Security.Credentials.WebAccountProvider: ...
    @winrt_commethod(7)
    def get_Invoked(self) -> win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommandInvokedHandler: ...
    Invoked = property(get_Invoked, None)
    WebAccountProvider = property(get_WebAccountProvider, None)
class IWebAccountProviderCommandFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.ApplicationSettings.IWebAccountProviderCommandFactory'
    _iid_ = Guid('{d5658a1b-b176-4776-8469-a9d3ff0b3f59}')
    @winrt_commethod(6)
    def CreateWebAccountProviderCommand(self, webAccountProvider: win32more.Windows.Security.Credentials.WebAccountProvider, invoked: win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommandInvokedHandler) -> win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommand: ...
class _SettingsCommand_Meta_(ComPtr.__class__):
    pass
class SettingsCommand(ComPtr, metaclass=_SettingsCommand_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Popups.IUICommand
    _classid_ = 'Windows.UI.ApplicationSettings.SettingsCommand'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.UI.ApplicationSettings.SettingsCommand.CreateSettingsCommand(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateSettingsCommand(cls: win32more.Windows.UI.ApplicationSettings.ISettingsCommandFactory, settingsCommandId: win32more.Windows.Win32.System.WinRT.IInspectable, label: WinRT_String, handler: win32more.Windows.UI.Popups.UICommandInvokedHandler) -> win32more.Windows.UI.ApplicationSettings.SettingsCommand: ...
    @winrt_mixinmethod
    def get_Label(self: win32more.Windows.UI.Popups.IUICommand) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Label(self: win32more.Windows.UI.Popups.IUICommand, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Invoked(self: win32more.Windows.UI.Popups.IUICommand) -> win32more.Windows.UI.Popups.UICommandInvokedHandler: ...
    @winrt_mixinmethod
    def put_Invoked(self: win32more.Windows.UI.Popups.IUICommand, value: win32more.Windows.UI.Popups.UICommandInvokedHandler) -> Void: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.UI.Popups.IUICommand) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Id(self: win32more.Windows.UI.Popups.IUICommand, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_classmethod
    def get_AccountsCommand(cls: win32more.Windows.UI.ApplicationSettings.ISettingsCommandStatics) -> win32more.Windows.UI.ApplicationSettings.SettingsCommand: ...
    Id = property(get_Id, put_Id)
    Invoked = property(get_Invoked, put_Invoked)
    Label = property(get_Label, put_Label)
    _SettingsCommand_Meta_.AccountsCommand = property(get_AccountsCommand, None)
class SettingsEdgeLocation(Enum, Int32):
    Right = 0
    Left = 1
class _SettingsPane_Meta_(ComPtr.__class__):
    pass
class SettingsPane(ComPtr, metaclass=_SettingsPane_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.ISettingsPane
    _classid_ = 'Windows.UI.ApplicationSettings.SettingsPane'
    @winrt_mixinmethod
    def add_CommandsRequested(self: win32more.Windows.UI.ApplicationSettings.ISettingsPane, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.ApplicationSettings.SettingsPane, win32more.Windows.UI.ApplicationSettings.SettingsPaneCommandsRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CommandsRequested(self: win32more.Windows.UI.ApplicationSettings.ISettingsPane, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.UI.ApplicationSettings.ISettingsPaneStatics) -> win32more.Windows.UI.ApplicationSettings.SettingsPane: ...
    @winrt_classmethod
    def Show(cls: win32more.Windows.UI.ApplicationSettings.ISettingsPaneStatics) -> Void: ...
    @winrt_classmethod
    def get_Edge(cls: win32more.Windows.UI.ApplicationSettings.ISettingsPaneStatics) -> win32more.Windows.UI.ApplicationSettings.SettingsEdgeLocation: ...
    _SettingsPane_Meta_.Edge = property(get_Edge, None)
    CommandsRequested = event()
class SettingsPaneCommandsRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.ISettingsPaneCommandsRequest
    _classid_ = 'Windows.UI.ApplicationSettings.SettingsPaneCommandsRequest'
    @winrt_mixinmethod
    def get_ApplicationCommands(self: win32more.Windows.UI.ApplicationSettings.ISettingsPaneCommandsRequest) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.UI.ApplicationSettings.SettingsCommand]: ...
    ApplicationCommands = property(get_ApplicationCommands, None)
class SettingsPaneCommandsRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.ISettingsPaneCommandsRequestedEventArgs
    _classid_ = 'Windows.UI.ApplicationSettings.SettingsPaneCommandsRequestedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.UI.ApplicationSettings.ISettingsPaneCommandsRequestedEventArgs) -> win32more.Windows.UI.ApplicationSettings.SettingsPaneCommandsRequest: ...
    Request = property(get_Request, None)
class SupportedWebAccountActions(Enum, UInt32):
    None_ = 0
    Reconnect = 1
    Remove = 2
    ViewDetails = 4
    Manage = 8
    More = 16
class WebAccountAction(Enum, Int32):
    Reconnect = 0
    Remove = 1
    ViewDetails = 2
    Manage = 3
    More = 4
class WebAccountCommand(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.IWebAccountCommand
    _classid_ = 'Windows.UI.ApplicationSettings.WebAccountCommand'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.UI.ApplicationSettings.WebAccountCommand.CreateWebAccountCommand(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWebAccountCommand(cls: win32more.Windows.UI.ApplicationSettings.IWebAccountCommandFactory, webAccount: win32more.Windows.Security.Credentials.WebAccount, invoked: win32more.Windows.UI.ApplicationSettings.WebAccountCommandInvokedHandler, actions: win32more.Windows.UI.ApplicationSettings.SupportedWebAccountActions) -> win32more.Windows.UI.ApplicationSettings.WebAccountCommand: ...
    @winrt_mixinmethod
    def get_WebAccount(self: win32more.Windows.UI.ApplicationSettings.IWebAccountCommand) -> win32more.Windows.Security.Credentials.WebAccount: ...
    @winrt_mixinmethod
    def get_Invoked(self: win32more.Windows.UI.ApplicationSettings.IWebAccountCommand) -> win32more.Windows.UI.ApplicationSettings.WebAccountCommandInvokedHandler: ...
    @winrt_mixinmethod
    def get_Actions(self: win32more.Windows.UI.ApplicationSettings.IWebAccountCommand) -> win32more.Windows.UI.ApplicationSettings.SupportedWebAccountActions: ...
    Actions = property(get_Actions, None)
    Invoked = property(get_Invoked, None)
    WebAccount = property(get_WebAccount, None)
class WebAccountCommandInvokedHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1ee6e459-1705-4a9a-b599-a0c3d6921973}')
    @winrt_commethod(3)
    def Invoke(self, command: win32more.Windows.UI.ApplicationSettings.WebAccountCommand, args: win32more.Windows.UI.ApplicationSettings.WebAccountInvokedArgs) -> Void: ...
class WebAccountInvokedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.IWebAccountInvokedArgs
    _classid_ = 'Windows.UI.ApplicationSettings.WebAccountInvokedArgs'
    @winrt_mixinmethod
    def get_Action(self: win32more.Windows.UI.ApplicationSettings.IWebAccountInvokedArgs) -> win32more.Windows.UI.ApplicationSettings.WebAccountAction: ...
    Action = property(get_Action, None)
class WebAccountProviderCommand(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.ApplicationSettings.IWebAccountProviderCommand
    _classid_ = 'Windows.UI.ApplicationSettings.WebAccountProviderCommand'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommand.CreateWebAccountProviderCommand(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWebAccountProviderCommand(cls: win32more.Windows.UI.ApplicationSettings.IWebAccountProviderCommandFactory, webAccountProvider: win32more.Windows.Security.Credentials.WebAccountProvider, invoked: win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommandInvokedHandler) -> win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommand: ...
    @winrt_mixinmethod
    def get_WebAccountProvider(self: win32more.Windows.UI.ApplicationSettings.IWebAccountProviderCommand) -> win32more.Windows.Security.Credentials.WebAccountProvider: ...
    @winrt_mixinmethod
    def get_Invoked(self: win32more.Windows.UI.ApplicationSettings.IWebAccountProviderCommand) -> win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommandInvokedHandler: ...
    Invoked = property(get_Invoked, None)
    WebAccountProvider = property(get_WebAccountProvider, None)
class WebAccountProviderCommandInvokedHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b7de5527-4c8f-42dd-84da-5ec493abdb9a}')
    @winrt_commethod(3)
    def Invoke(self, command: win32more.Windows.UI.ApplicationSettings.WebAccountProviderCommand) -> Void: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Preview.InkWorkspace
import win32more.Windows.Foundation
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Win32.System.WinRT
class IInkWorkspaceHostedAppManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.InkWorkspace.IInkWorkspaceHostedAppManager'
    _iid_ = Guid('{fe0a7990-5e59-4bb7-8a63-7d218cd96300}')
    @winrt_commethod(6)
    def SetThumbnailAsync(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncAction: ...
class IInkWorkspaceHostedAppManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.InkWorkspace.IInkWorkspaceHostedAppManagerStatics'
    _iid_ = Guid('{cbfd8cc5-a162-4bc4-84ee-e8716d5233c5}')
    @winrt_commethod(6)
    def GetForCurrentApp(self) -> win32more.Windows.ApplicationModel.Preview.InkWorkspace.InkWorkspaceHostedAppManager: ...
class InkWorkspaceHostedAppManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Preview.InkWorkspace.IInkWorkspaceHostedAppManager
    _classid_ = 'Windows.ApplicationModel.Preview.InkWorkspace.InkWorkspaceHostedAppManager'
    @winrt_mixinmethod
    def SetThumbnailAsync(self: win32more.Windows.ApplicationModel.Preview.InkWorkspace.IInkWorkspaceHostedAppManager, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def GetForCurrentApp(cls: win32more.Windows.ApplicationModel.Preview.InkWorkspace.IInkWorkspaceHostedAppManagerStatics) -> win32more.Windows.ApplicationModel.Preview.InkWorkspace.InkWorkspaceHostedAppManager: ...
PreviewInkWorkspaceContract: UInt32 = 65536


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Diagnostics.Debug
import win32more.Windows.Win32.System.Kernel
OBJ_HANDLE_TAGBITS: Int32 = 3
RTL_BALANCED_NODE_RESERVED_PARENT_MASK: UInt32 = 3
NULL64: UInt32 = 0
MAXUCHAR: UInt32 = 255
MAXUSHORT: UInt32 = 65535
MAXULONG: UInt32 = 4294967295
@winfunctype('ntdll.dll')
def RtlInitializeSListHead(ListHead: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_HEADER)) -> Void: ...
@winfunctype('ntdll.dll')
def RtlFirstEntrySList(ListHead: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_HEADER)) -> POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY): ...
@winfunctype('ntdll.dll')
def RtlInterlockedPopEntrySList(ListHead: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_HEADER)) -> POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY): ...
@winfunctype('ntdll.dll')
def RtlInterlockedPushEntrySList(ListHead: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_HEADER), ListEntry: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY)) -> POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY): ...
@winfunctype('ntdll.dll')
def RtlInterlockedPushListSListEx(ListHead: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_HEADER), List: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY), ListEnd: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY), Count: UInt32) -> POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY): ...
@winfunctype('ntdll.dll')
def RtlInterlockedFlushSList(ListHead: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_HEADER)) -> POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY): ...
@winfunctype('ntdll.dll')
def RtlQueryDepthSList(ListHead: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_HEADER)) -> UInt16: ...
COMPARTMENT_ID = Int32
UNSPECIFIED_COMPARTMENT_ID: win32more.Windows.Win32.System.Kernel.COMPARTMENT_ID = 0
DEFAULT_COMPARTMENT_ID: win32more.Windows.Win32.System.Kernel.COMPARTMENT_ID = 1
class CSTRING(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: win32more.Windows.Win32.Foundation.PSTR
EVENT_TYPE = Int32
NotificationEvent: win32more.Windows.Win32.System.Kernel.EVENT_TYPE = 0
SynchronizationEvent: win32more.Windows.Win32.System.Kernel.EVENT_TYPE = 1
EXCEPTION_DISPOSITION = Int32
ExceptionContinueExecution: win32more.Windows.Win32.System.Kernel.EXCEPTION_DISPOSITION = 0
ExceptionContinueSearch: win32more.Windows.Win32.System.Kernel.EXCEPTION_DISPOSITION = 1
ExceptionNestedException: win32more.Windows.Win32.System.Kernel.EXCEPTION_DISPOSITION = 2
ExceptionCollidedUnwind: win32more.Windows.Win32.System.Kernel.EXCEPTION_DISPOSITION = 3
class EXCEPTION_REGISTRATION_RECORD(Structure):
    Next: POINTER(win32more.Windows.Win32.System.Kernel.EXCEPTION_REGISTRATION_RECORD)
    Handler: win32more.Windows.Win32.System.Kernel.EXCEPTION_ROUTINE
@winfunctype_pointer
def EXCEPTION_ROUTINE(ExceptionRecord: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.EXCEPTION_RECORD), EstablisherFrame: VoidPtr, ContextRecord: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.CONTEXT), DispatcherContext: VoidPtr) -> win32more.Windows.Win32.System.Kernel.EXCEPTION_DISPOSITION: ...
if ARCH in 'X64,ARM64':
    class FLOATING_SAVE_AREA(Structure):
        ControlWord: UInt32
        StatusWord: UInt32
        TagWord: UInt32
        ErrorOffset: UInt32
        ErrorSelector: UInt32
        DataOffset: UInt32
        DataSelector: UInt32
        RegisterArea: Byte * 80
        Cr0NpxState: UInt32
elif ARCH in 'X86':
    class FLOATING_SAVE_AREA(Structure):
        ControlWord: UInt32
        StatusWord: UInt32
        TagWord: UInt32
        ErrorOffset: UInt32
        ErrorSelector: UInt32
        DataOffset: UInt32
        DataSelector: UInt32
        RegisterArea: Byte * 80
        Spare0: UInt32
class LIST_ENTRY(Structure):
    Flink: POINTER(win32more.Windows.Win32.System.Kernel.LIST_ENTRY)
    Blink: POINTER(win32more.Windows.Win32.System.Kernel.LIST_ENTRY)
class LIST_ENTRY32(Structure):
    Flink: UInt32
    Blink: UInt32
class LIST_ENTRY64(Structure):
    Flink: UInt64
    Blink: UInt64
NT_PRODUCT_TYPE = Int32
NtProductWinNt: win32more.Windows.Win32.System.Kernel.NT_PRODUCT_TYPE = 1
NtProductLanManNt: win32more.Windows.Win32.System.Kernel.NT_PRODUCT_TYPE = 2
NtProductServer: win32more.Windows.Win32.System.Kernel.NT_PRODUCT_TYPE = 3
class NT_TIB(Structure):
    ExceptionList: POINTER(win32more.Windows.Win32.System.Kernel.EXCEPTION_REGISTRATION_RECORD)
    StackBase: VoidPtr
    StackLimit: VoidPtr
    SubSystemTib: VoidPtr
    Anonymous: _Anonymous_e__Union
    ArbitraryUserPointer: VoidPtr
    Self: POINTER(win32more.Windows.Win32.System.Kernel.NT_TIB)
    class _Anonymous_e__Union(Union):
        FiberData: VoidPtr
        Version: UInt32
class OBJECTID(Structure):
    Lineage: Guid
    Uniquifier: UInt32
class PROCESSOR_NUMBER(Structure):
    Group: UInt16
    Number: Byte
    Reserved: Byte
class QUAD(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        UseThisFieldToCopy: Int64
        DoNotUseThisField: Double
class RTL_BALANCED_NODE(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        Children: POINTER(win32more.Windows.Win32.System.Kernel.RTL_BALANCED_NODE) * 2
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Left: POINTER(win32more.Windows.Win32.System.Kernel.RTL_BALANCED_NODE)
            Right: POINTER(win32more.Windows.Win32.System.Kernel.RTL_BALANCED_NODE)
    class _Anonymous2_e__Union(Union):
        Red: Annotated[Byte, 1]
        Balance: Annotated[Byte, 2]
        ParentValue: UIntPtr
class SINGLE_LIST_ENTRY(Structure):
    Next: POINTER(win32more.Windows.Win32.System.Kernel.SINGLE_LIST_ENTRY)
class SINGLE_LIST_ENTRY32(Structure):
    Next: UInt32
class SLIST_ENTRY(Structure):
    Next: POINTER(win32more.Windows.Win32.System.Kernel.SLIST_ENTRY)
if ARCH in 'ARM64':
    class SLIST_HEADER(Union):
        Anonymous: _Anonymous_e__Struct
        HeaderArm64: _HeaderArm64_e__Struct
        class _Anonymous_e__Struct(Structure):
            Alignment: UInt64
            Region: UInt64
        class _HeaderArm64_e__Struct(Structure):
            Depth: Annotated[UInt64, 16]
            Sequence: Annotated[UInt64, 48]
            Reserved: Annotated[UInt64, 4]
            NextEntry: Annotated[UInt64, 60]
elif ARCH in 'X64':
    class SLIST_HEADER(Union):
        Anonymous: _Anonymous_e__Struct
        HeaderX64: _HeaderX64_e__Struct
        class _Anonymous_e__Struct(Structure):
            Alignment: UInt64
            Region: UInt64
        class _HeaderX64_e__Struct(Structure):
            Depth: Annotated[UInt64, 16]
            Sequence: Annotated[UInt64, 48]
            Reserved: Annotated[UInt64, 4]
            NextEntry: Annotated[UInt64, 60]
elif ARCH in 'X86':
    class SLIST_HEADER(Union):
        Alignment: UInt64
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Next: win32more.Windows.Win32.System.Kernel.SINGLE_LIST_ENTRY
            Depth: UInt16
            CpuId: UInt16
class STRING(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: win32more.Windows.Win32.Foundation.PSTR
class STRING32(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: UInt32
class STRING64(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Buffer: UInt64
SUITE_TYPE = Int32
SmallBusiness: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 0
Enterprise: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 1
BackOffice: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 2
CommunicationServer: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 3
TerminalServer: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 4
SmallBusinessRestricted: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 5
EmbeddedNT: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 6
DataCenter: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 7
SingleUserTS: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 8
Personal: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 9
Blade: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 10
EmbeddedRestricted: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 11
SecurityAppliance: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 12
StorageServer: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 13
ComputeServer: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 14
WHServer: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 15
PhoneNT: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 16
MultiUserTS: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 17
MaxSuiteType: win32more.Windows.Win32.System.Kernel.SUITE_TYPE = 18
TIMER_TYPE = Int32
NotificationTimer: win32more.Windows.Win32.System.Kernel.TIMER_TYPE = 0
SynchronizationTimer: win32more.Windows.Win32.System.Kernel.TIMER_TYPE = 1
WAIT_TYPE = Int32
WaitAll: win32more.Windows.Win32.System.Kernel.WAIT_TYPE = 0
WaitAny: win32more.Windows.Win32.System.Kernel.WAIT_TYPE = 1
WaitNotification: win32more.Windows.Win32.System.Kernel.WAIT_TYPE = 2
WaitDequeue: win32more.Windows.Win32.System.Kernel.WAIT_TYPE = 3
WaitDpc: win32more.Windows.Win32.System.Kernel.WAIT_TYPE = 4
class WNF_STATE_NAME(Structure):
    Data: UInt32 * 2


make_ready(__name__)
